/*******************************************************************************
 * Copyright (c) 2003, 2004 Texas Instruments Incorporated and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     Texas Instruments - Initial API and implementation
 *******************************************************************************/

package org.eclipse.cdt.debug.mi.core.command;

import org.eclipse.cdt.debug.mi.core.MIException;
import org.eclipse.cdt.debug.mi.core.output.MIDataListRegisterGroupsInfo;
import org.eclipse.cdt.debug.mi.core.output.MIInfo;
import org.eclipse.cdt.debug.mi.core.output.MIOutput;

/**
 * Custom command for requesting the register groups.
 * It is not yet in the GDB stream.
 * 
 * -data-list-register-groups 
 *
 * The format of the command is: 
 * 		IN:(gdb)-data-list-register-groups 
 * 		OUT:^done,register-groups= [{name="r0", group="GRP1"},{name="r8",group="GRP2"}]
 * 
 * It is similar of the command: "-data-list-register-values".
 * 
 * The register group names are case sensitive.
 *  * The register groups appear in the Register View in order they are returns from 
 * the command "-data-list-register-groups".
 * 
 * The registers appear in the groups in the order they are returned from the 
 * command "-data-list-register-names".
 * The register names are case sensitive.
 * 
 * If the debugger doesnt support the command "-data-list-register-groups" all 
 * registers are added to the "Main" group.
 * If there is a register returned by the command "-data-list-register-names" but not 
 * in the command "-data-list-register-groups" it is added to the "Main" group. 
 * The main group itself is added first to the Register view.
 * If there is a register returned by the command "-data-list-register-groups" but not in 
 * the command "-data-list-register-names" the register is ignored.
 */
public class MIDataListRegisterGroups extends MICommand {

	/**
	 * Default consturctor.
	 */
	public MIDataListRegisterGroups() {
		super("-data-list-register-groups"); //$NON-NLS-1$
	}
	
	/**
	 * Returns the register group information read form the MI/GDB stream.
	 * 
	 * @return the register group information read form the MI/GDB stream.
	 * @throws MIException
	 */
	public MIDataListRegisterGroupsInfo getMIDataListRegisterGroupsInfo() throws MIException {
		return (MIDataListRegisterGroupsInfo)getMIInfo();
	}

	/**
	 * Returns the register group information read form the MI/GDB stream.
	 * 
	 * @return the register group information read form the MI/GDB stream.
	 * @throws MIException
	 */
	public MIInfo getMIInfo() throws MIException {
		MIInfo info = null;
		MIOutput out = getMIOutput();
		if (out != null) {
			info = new MIDataListRegisterGroupsInfo(out);
			if (info.isError()) {
				throwMIException(info, out);
			}
		}
		return info;
	}
}
